@@ -84,6 +84,32 @@ class jac_api():
                                nd=faux.active_gph(), ctx=ctx,
                                profiling=profiling)
 
+    @interface.cli_api(cli_args=['file'])
+    def jac_dot(self, file: str, walk: str = 'init', ctx: dict = {},
+                profiling: bool = False):
+        """
+        Command line tooling for a walker then output graph in both .jac code
+        files and .jir executables
+        """
+        if(not os.path.isfile(file)):
+            ret = "File does not exsist!"
+            return ret
+        is_jir = file.endswith(".jir")
+        faux = self.faux_master()
+        with open(file, 'r') as file:
+            if(is_jir):
+                faux.sentinel_register()
+                faux.sentinel_set(snt=faux.active_snt(),
+                                  code=file.read(), mode='ir')
+            else:
+                ret = faux.sentinel_register(code=file.read(), auto_run='')
+                if('success' in ret and not ret['success']):
+                    return ret
+        faux.walker_run(name=walk, snt=faux.active_snt(),
+                        nd=faux.active_gph(), ctx=ctx,
+                        profiling=profiling)
+        return faux.graph_get(gph=faux.active_gph(), mode='dot')
+
     def faux_master(self):
         from jaseci.element.super_master import super_master
         from jaseci.utils.mem_hook import mem_hook
