@@ -30,7 +30,12 @@ class interp(machine_state):
         if(kid[0].name == 'has_stmt'):
             self.run_has_stmt(kid[0], obj)
         elif(kid[0].name == 'can_stmt'):
-            self.run_can_stmt(kid[0], obj)
+            if(obj.j_type == 'walker'):
+                self.run_can_stmt(kid[0], obj)
+            else:
+                obj = self.get_arch_for(obj)
+                if(not obj._can_compiled_flag):
+                    self.run_can_stmt(kid[0], obj)
 
     def run_has_stmt(self, jac_ast, obj):
         """
@@ -111,11 +116,11 @@ class interp(machine_state):
             if(len(kid) > 0 and kid[0].name == 'event_clause'):
                 action_type, access_list = self.run_event_clause(kid[0])
                 kid = kid[1:]
-            if (not isinstance(obj, node) and action_type != 'activity'):
-                self.rt_warn(
-                    "Only nodes can have on entry/exit, treating as activity",
-                    kid[0])
-                action_type = 'activity'
+            # if (not isinstance(obj, node) and action_type != 'activity'):
+            #     self.rt_warn(
+            #         "Only nodes has on entry/exit, treating as activity",
+            #         kid[0])
+            #     action_type = 'activity'
             if (kid[0].name == 'code_block'):
                 act = action(
                     m_id=self._m_id,
@@ -200,7 +205,6 @@ class interp(machine_state):
     def run_code_block(self, jac_ast):
         """
         code_block: LBRACE statement* RBRACE | COLON statement;
-        TODO: Handle breaks and continues
         """
         kid = self.set_cur_ast(jac_ast)
         for i in kid:
@@ -388,13 +392,21 @@ class interp(machine_state):
 
     def run_report_action(self, jac_ast):
         """
-        report_action: KW_REPORT expression SEMI;
+        report_action:
+            KW_REPORT expression SEMI
+            | KW_REPORT DOT NAME EQ INT SEMI;
         """
         kid = self.set_cur_ast(jac_ast)
-        report = self.run_expression(kid[1]).wrap(serialize_mode=True)
-        if(not is_jsonable(report)):
-            self.rt_error(f'Report not Json serializable', kid[0])
-        self.report.append(copy(report))
+        if(kid[1].name == "DOT"):
+            if(kid[2].token_text() in ['status', 'status_code']):
+                self.report_status = int(kid[4].token_text())
+            else:
+                self.rt_error(f'Invalid report attribute to set', kid[2])
+        else:
+            report = self.run_expression(kid[1]).wrap(serialize_mode=True)
+            if(not is_jsonable(report)):
+                self.rt_error(f'Report not Json serializable', kid[0])
+            self.report.append(copy(report))
 
     def run_expression(self, jac_ast):
         """
@@ -738,10 +750,11 @@ class interp(machine_state):
         elif (kid[0].name == 'DBL_COLON'):
             if(len(kid) > 2):
                 self.run_spawn_ctx(kid[2], atom_res.value)
+            arch = self.get_arch_for(atom_res.value)
             self.call_ability(
                 nd=atom_res.value,
                 name=kid[1].token_text(),
-                act_list=atom_res.value.activity_action_ids)
+                act_list=arch.activity_action_ids)
             return atom_res
 
     def run_ref(self, jac_ast):
@@ -1234,7 +1247,8 @@ class interp(machine_state):
         """
         kid = self.set_cur_ast(jac_ast)
         idx = self.run_expression(kid[1]).value
-        if(type(idx) == str and idx not in atom_res.value.keys()):
+        if(type(idx) == str and idx not in atom_res.value.keys() and
+           not self._assign_mode):
             self.rt_error(f'Key {idx} not found in object/dict.', kid[1])
         if(kid[2].name == "RSQUARE"):
             if(not self.rt_check_type(idx, [int, str], kid[1])):
@@ -1345,6 +1359,8 @@ class interp(machine_state):
         ret = jac_value(self, value=walk.anchor_value())
         ret.unwrap()
         self.report += walk.report
+        if(walk.report_status):
+            self.report_status = walk.report_status
         self.runtime_errors += walk.runtime_errors
         walk.destroy()
         return ret
@@ -1455,13 +1471,16 @@ class interp(machine_state):
 
     def call_ability(self, nd, name, act_list):
         m = interp(parent_override=self.parent(), caller=self)
+        arch = self.get_arch_for(nd)
         m.push_scope(jac_scope(parent=nd,
                                has_obj=nd,
-                               action_sets=[nd.activity_action_ids]))
+                               action_sets=[arch.activity_action_ids]))
         m._jac_scope.inherit_agent_refs(self._jac_scope)
         m.run_code_block(jac_ir_to_ast(
             act_list.get_obj_by_name(name).value))
         self.report += m.report
+        if(m.report_status):
+            self.report_status = m.report_status
         self.runtime_errors += m.runtime_errors
 
     def run_rule(self, jac_ast, *args):
