@@ -384,8 +384,8 @@ class jac_tests(TestCaseHelper, TestCase):
         test_walker.run()
         self.assertEqual(2, len(test_walker.report[0][0].keys()))
         self.assertGreaterEqual(len(test_walker.report[0][1].keys()), 7)
-        self.assertLess(len(test_walker.report[0][1].keys()), 16)
-        self.assertGreaterEqual(len(test_walker.report[0][2].keys()), 16)
+        self.assertLess(len(test_walker.report[0][1].keys()), 14)
+        self.assertGreaterEqual(len(test_walker.report[0][2].keys()), 14)
 
     def test_spawn_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
@@ -738,7 +738,6 @@ class jac_tests(TestCaseHelper, TestCase):
                       test_walker.runtime_errors[0])
 
     def test_root_type_nodes(self):
-        self.logger_on()
         gph = graph(m_id='anon', h=mem_hook())
         sent = sentinel(m_id='anon', h=gph._h)
         sent.register_code(jtc.root_type_nodes)
@@ -781,3 +780,27 @@ class jac_tests(TestCaseHelper, TestCase):
         test_walker.run()
         report = test_walker.report
         self.assertEqual(report, [True, True])
+
+    def test_no_error_on_dict_key_assign(self):
+        gph = graph(m_id='anon', h=mem_hook())
+        sent = sentinel(m_id='anon', h=gph._h)
+        sent.register_code(jtc.no_error_on_dict_key_assign)
+        test_walker = \
+            sent.walker_ids.get_obj_by_name('init')
+        test_walker.prime(gph)
+        test_walker.run()
+        report = test_walker.report
+        self.assertEqual(report, [{'b': 4}])
+        self.assertEqual(len(test_walker.runtime_errors), 0)
+
+    def test_report_status(self):
+        gph = graph(m_id='anon', h=mem_hook())
+        sent = sentinel(m_id='anon', h=gph._h)
+        sent.register_code(jtc.report_status)
+        test_walker = \
+            sent.walker_ids.get_obj_by_name('init')
+        test_walker.prime(gph)
+        test_walker.run()
+        report = test_walker.report
+        self.assertEqual(report, ['hello'])
+        self.assertEqual(test_walker.report_status, 302)
